@@ -52,7 +52,7 @@ edit_dialog_clicked (GtkWidget  *widget,
                     NULL);
   file = g_filename_from_utf8 (gtk_entry_get_text (GTK_ENTRY (editdlg->entry)),
                                                         -1, NULL, NULL, NULL);
-  if (fileio_isfile (file))
+  if (g_file_test (file, G_FILE_TEST_EXISTS))
     {
       gtk_file_chooser_set_filename (GTK_FILE_CHOOSER (dialog), file);
     }
@@ -63,7 +63,7 @@ edit_dialog_clicked (GtkWidget  *widget,
       dir = g_path_get_dirname (file);
       path = fileio_get_full_path (dir);
       g_free (dir);
-      if (fileio_isfile (path))
+      if (g_file_test (path, G_FILE_TEST_EXISTS))
         gtk_file_chooser_set_current_folder (GTK_FILE_CHOOSER (dialog), path);
       g_free (path);
     }
@@ -190,6 +190,9 @@ edit_dialog (MmaidWindow *mmaid)
                             (title,
                             GTK_WINDOW (window),
                             GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
+#ifdef G_OS_WIN32
+#else /* not G_OS_WIN32 */
+#endif /* not G_OS_WIN32 */
                             GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
                             GTK_STOCK_OK, GTK_RESPONSE_OK,
                             NULL);
@@ -199,8 +202,13 @@ edit_dialog (MmaidWindow *mmaid)
                             (_("Edit"),
                             GTK_WINDOW (window),
                             GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
+#ifdef G_OS_WIN32
+                            GTK_STOCK_OK, GTK_RESPONSE_OK,
+                            GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+#else /* not G_OS_WIN32 */
                             GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
                             GTK_STOCK_OK, GTK_RESPONSE_OK,
+#endif /* not G_OS_WIN32 */
                             NULL);
 #endif /* not GTK_CHECK_VERSION(2,6,0) */
   g_signal_connect (G_OBJECT (editdlg.dialog), "key-press-event",
