@@ -535,6 +535,8 @@ file_open_db (const gchar *file,
     {
       ID3Tag *id3tag;
 
+      while (gtk_events_pending ())
+        gtk_main_iteration ();
       id3tag = g_malloc0 (sizeof (ID3Tag));
       id3tag->file    = g_strconcat (dir, mi_c[i].str[METAINFO_PATH], NULL);
       g_free (mi_c[i].str[METAINFO_PATH]);
@@ -622,6 +624,8 @@ file_open_list (const gchar *file,
           {
             gchar *str, *path;
 
+            while (gtk_events_pending ())
+              gtk_main_iteration ();
             str = file_path_convert (ary[j], -1, charset[i], TRUE);
             if (!str)
               break;
@@ -664,6 +668,8 @@ file_open_list (const gchar *file,
       gchar *path;
       ID3Tag *id3tag;
 
+      while (gtk_events_pending ())
+        gtk_main_iteration ();
       path = g_list_nth_data (glist, i);
       id3tag = g_malloc0 (sizeof (ID3Tag));
       id3tag->file  = fileio_get_full_path (path);
