@@ -340,8 +340,13 @@ genre_dialog (void)
                             (_("Genre"),
                             GTK_WINDOW (window),
                             GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
+#ifdef G_OS_WIN32
+                            GTK_STOCK_OK, GTK_RESPONSE_OK,
+                            GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+#else /* not G_OS_WIN32 */
                             GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
                             GTK_STOCK_OK, GTK_RESPONSE_OK,
+#endif /* not G_OS_WIN32 */
                             NULL);
   gtk_window_set_default_size (GTK_WINDOW (gnrdlg.dialog),
                     gdk_screen_width () * 2 / 3, gdk_screen_height () * 2 / 3);
